Documentation
¶
Overview ¶
Code generated by internal/generate/tags/main.go; DO NOT EDIT.
Index ¶
- func DataSourceDelegatedAdministrators() *schema.Resource
- func DataSourceDelegatedServices() *schema.Resource
- func DataSourceOrganization() *schema.Resource
- func DataSourceOrganizationalUnits() *schema.Resource
- func DataSourceResourceTags() *schema.Resource
- func DecodeOrganizationDelegatedAdministratorID(id string) (string, string, error)
- func DecodePolicyAttachmentID(id string) (string, string, error)
- func FindAccountByID(conn *organizations.Organizations, id string) (*organizations.Account, error)
- func FindOrganization(conn *organizations.Organizations) (*organizations.Organization, error)
- func FlattenOrganizationalUnits(ous []*organizations.OrganizationalUnit) []map[string]interface{}
- func FlattenRoots(roots []*organizations.Root) []map[string]interface{}
- func KeyValueTags(tags []*organizations.Tag) tftags.KeyValueTags
- func ListTags(conn organizationsiface.OrganizationsAPI, identifier string) (tftags.KeyValueTags, error)
- func ListTagsWithContext(ctx context.Context, conn organizationsiface.OrganizationsAPI, ...) (tftags.KeyValueTags, error)
- func ResourceAccount() *schema.Resource
- func ResourceDelegatedAdministrator() *schema.Resource
- func ResourceOrganization() *schema.Resource
- func ResourceOrganizationalUnit() *schema.Resource
- func ResourcePolicy() *schema.Resource
- func ResourcePolicyAttachment() *schema.Resource
- func Tags(tags tftags.KeyValueTags) []*organizations.Tag
- func UpdateTags(conn organizationsiface.OrganizationsAPI, identifier string, ...) error
- func UpdateTagsWithContext(ctx context.Context, conn organizationsiface.OrganizationsAPI, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataSourceOrganization ¶
func DataSourceResourceTags ¶
func FindAccountByID ¶
func FindAccountByID(conn *organizations.Organizations, id string) (*organizations.Account, error)
func FindOrganization ¶
func FindOrganization(conn *organizations.Organizations) (*organizations.Organization, error)
func FlattenOrganizationalUnits ¶
func FlattenOrganizationalUnits(ous []*organizations.OrganizationalUnit) []map[string]interface{}
func FlattenRoots ¶
func FlattenRoots(roots []*organizations.Root) []map[string]interface{}
func KeyValueTags ¶
func KeyValueTags(tags []*organizations.Tag) tftags.KeyValueTags
KeyValueTags creates tftags.KeyValueTags from organizations service tags.
func ListTags ¶
func ListTags(conn organizationsiface.OrganizationsAPI, identifier string) (tftags.KeyValueTags, error)
ListTags lists organizations service tags. The identifier is typically the Amazon Resource Name (ARN), although it may also be a different identifier depending on the service.
func ListTagsWithContext ¶
func ListTagsWithContext(ctx context.Context, conn organizationsiface.OrganizationsAPI, identifier string) (tftags.KeyValueTags, error)
func ResourceAccount ¶
func ResourceOrganization ¶
func ResourcePolicy ¶
func Tags ¶
func Tags(tags tftags.KeyValueTags) []*organizations.Tag
Tags returns organizations service tags.
func UpdateTags ¶
func UpdateTags(conn organizationsiface.OrganizationsAPI, identifier string, oldTags interface{}, newTags interface{}) error
UpdateTags updates organizations service tags. The identifier is typically the Amazon Resource Name (ARN), although it may also be a different identifier depending on the service.
func UpdateTagsWithContext ¶
func UpdateTagsWithContext(ctx context.Context, conn organizationsiface.OrganizationsAPI, identifier string, oldTagsMap interface{}, newTagsMap interface{}) error
Types ¶
This section is empty.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.